@@ -11,6 +11,7 @@
 # Copyright (c) 2013 Bernardo Heynemann heynemann@gmail.com
 
 import re
+from datetime import datetime
 
 try:
     from six import string_types, binary_type
@@ -22,17 +23,20 @@ import numbers
 
 from preggy import create_assertions
 
-
-REMOVE_COLORS_REGEXES = [
-    re.compile('\033\[[0-9]*m', re.UNICODE),
-    re.compile('\x1b\[[0-9]*m', re.UNICODE),
-    re.compile('\x03\[[0-9]*m', re.UNICODE),
-]
+DATE_THRESHOLD = 5.0
 
 
 #-------------------------------------------------------------------------------------------------
 # Helpers
 #-------------------------------------------------------------------------------------------------
+REMOVE_COLORS_REGEX = re.compile(
+    r'(\033|\x1b|\x03)'  # prefixes
+    r'\['                # non-regex bracket
+    r'[0-9]*m',          # suffix
+    re.UNICODE
+)
+
+
 def _match_alike(expected, topic):
     '''Asserts the "like"-ness of `topic` and `expected` according to their types.'''
     if topic is None:
@@ -45,6 +49,8 @@ def _match_alike(expected, topic):
         return _compare_lists(expected, topic)
     if isinstance(topic, dict):
         return _compare_dicts(expected, topic)
+    if isinstance(topic, datetime):
+        return _compare_datetime(expected, topic)
     raise RuntimeError('Could not compare {expected} and {topic}'.format(expected=expected, topic=topic))
 
 
@@ -59,9 +65,8 @@ def _compare_strings(expected, topic):
         expected = expected.decode('utf-8')
 
     _filter_str = lambda s: s.strip().lower().replace(' ', '').replace('\n', '')
-    for regex in REMOVE_COLORS_REGEXES:
-        expected = regex.sub('', expected)
-        topic = regex.sub('', topic)
+    expected = REMOVE_COLORS_REGEX.sub('', expected)
+    topic = REMOVE_COLORS_REGEX.sub('', topic)
 
     expected = _filter_str(expected)
     topic = _filter_str(topic)
@@ -74,6 +79,10 @@ def _compare_strings(expected, topic):
     return expected == _filter_str(topic)
 
 
+def _compare_datetime(expected, topic):
+    return (topic - expected).total_seconds > DATE_THRESHOLD
+
+
 def _compare_numbers(expected, topic):
     '''Asserts the "like"-ness of `topic` and `expected` as Numbers.'''
     FALSE_CONDITIONS = (not isinstance(topic, numbers.Number),
